'use strict';

var pieces = require('@sapphire/pieces');
var Identifiers_cjs = require('../lib/errors/Identifiers.cjs');
var number_cjs = require('../lib/resolvers/number.cjs');
var Argument_cjs = require('../lib/structures/Argument.cjs');

var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var _CoreArgument = class _CoreArgument extends Argument_cjs.Argument {
  constructor(context) {
    super(context, { name: "number" });
    this.messages = {
      [Identifiers_cjs.Identifiers.ArgumentNumberTooSmall]: ({ minimum }) => `The given number must be greater than ${minimum}.`,
      [Identifiers_cjs.Identifiers.ArgumentNumberTooLarge]: ({ maximum }) => `The given number must be less than ${maximum}.`,
      [Identifiers_cjs.Identifiers.ArgumentNumberError]: () => "The argument did not resolve to a valid number."
    };
  }
  run(parameter, context) {
    const resolved = number_cjs.resolveNumber(parameter, { minimum: context.minimum, maximum: context.maximum });
    return resolved.mapErrInto(
      (identifier) => this.error({
        parameter,
        identifier,
        message: this.messages[identifier](context),
        context
      })
    );
  }
};
__name(_CoreArgument, "CoreArgument");
var CoreArgument = _CoreArgument;
void pieces.container.stores.loadPiece({
  name: "number",
  piece: CoreArgument,
  store: "arguments"
});

exports.CoreArgument = CoreArgument;
//# sourceMappingURL=out.js.map
//# sourceMappingURL=CoreNumber.cjs.map