'use strict';

var ApplicationCommandRegistries_cjs = require('./lib/utils/application-commands/ApplicationCommandRegistries.cjs');
var ClientPermissions_cjs = require('./preconditions/ClientPermissions.cjs');
var Cooldown_cjs = require('./preconditions/Cooldown.cjs');
var DMOnly_cjs = require('./preconditions/DMOnly.cjs');
var Enabled_cjs = require('./preconditions/Enabled.cjs');
var GuildNewsOnly_cjs = require('./preconditions/GuildNewsOnly.cjs');
var GuildNewsThreadOnly_cjs = require('./preconditions/GuildNewsThreadOnly.cjs');
var GuildOnly_cjs = require('./preconditions/GuildOnly.cjs');
var GuildPrivateThreadOnly_cjs = require('./preconditions/GuildPrivateThreadOnly.cjs');
var GuildPublicThreadOnly_cjs = require('./preconditions/GuildPublicThreadOnly.cjs');
var GuildTextOnly_cjs = require('./preconditions/GuildTextOnly.cjs');
var GuildThreadOnly_cjs = require('./preconditions/GuildThreadOnly.cjs');
var GuildVoiceOnly_cjs = require('./preconditions/GuildVoiceOnly.cjs');
var NSFW_cjs = require('./preconditions/NSFW.cjs');
var RunIn_cjs = require('./preconditions/RunIn.cjs');
var UserPermissions_cjs = require('./preconditions/UserPermissions.cjs');
var pieces = require('@sapphire/pieces');
var result = require('@sapphire/result');
var SapphireClient_cjs = require('./lib/SapphireClient.cjs');
var ArgumentError_cjs = require('./lib/errors/ArgumentError.cjs');
var Identifiers_cjs = require('./lib/errors/Identifiers.cjs');
var PreconditionError_cjs = require('./lib/errors/PreconditionError.cjs');
var UserError_cjs = require('./lib/errors/UserError.cjs');
var Args_cjs = require('./lib/parsers/Args.cjs');
var Plugin_cjs = require('./lib/plugins/Plugin.cjs');
var PluginManager_cjs = require('./lib/plugins/PluginManager.cjs');
var symbols_cjs = require('./lib/plugins/symbols.cjs');
var index_cjs = require('./lib/precondition-resolvers/index.cjs');
var index_cjs$1 = require('./lib/resolvers/index.cjs');
var Argument_cjs = require('./lib/structures/Argument.cjs');
var ArgumentStore_cjs = require('./lib/structures/ArgumentStore.cjs');
var Command_cjs = require('./lib/structures/Command.cjs');
var CommandStore_cjs = require('./lib/structures/CommandStore.cjs');
var InteractionHandler_cjs = require('./lib/structures/InteractionHandler.cjs');
var InteractionHandlerStore_cjs = require('./lib/structures/InteractionHandlerStore.cjs');
var Listener_cjs = require('./lib/structures/Listener.cjs');
var ListenerLoaderStrategy_cjs = require('./lib/structures/ListenerLoaderStrategy.cjs');
var ListenerStore_cjs = require('./lib/structures/ListenerStore.cjs');
var Precondition_cjs = require('./lib/structures/Precondition.cjs');
var PreconditionStore_cjs = require('./lib/structures/PreconditionStore.cjs');
var ArgumentContexts_cjs = require('./lib/types/ArgumentContexts.cjs');
var CommandTypes_cjs = require('./lib/types/CommandTypes.cjs');
var Enums_cjs = require('./lib/types/Enums.cjs');
var Events_cjs = require('./lib/types/Events.cjs');
var ApplicationCommandRegistry_cjs = require('./lib/utils/application-commands/ApplicationCommandRegistry.cjs');
var ILogger_cjs = require('./lib/utils/logger/ILogger.cjs');
var Logger_cjs = require('./lib/utils/logger/Logger.cjs');
var IPreconditionContainer_cjs = require('./lib/utils/preconditions/IPreconditionContainer.cjs');
var PreconditionContainerArray_cjs = require('./lib/utils/preconditions/PreconditionContainerArray.cjs');
var PreconditionContainerSingle_cjs = require('./lib/utils/preconditions/PreconditionContainerSingle.cjs');
var IPreconditionCondition_cjs = require('./lib/utils/preconditions/conditions/IPreconditionCondition.cjs');
var PreconditionConditionAnd_cjs = require('./lib/utils/preconditions/conditions/PreconditionConditionAnd.cjs');
var PreconditionConditionOr_cjs = require('./lib/utils/preconditions/conditions/PreconditionConditionOr.cjs');
var ClientPermissionsPrecondition_cjs = require('./lib/utils/preconditions/containers/ClientPermissionsPrecondition.cjs');
var UserPermissionsPrecondition_cjs = require('./lib/utils/preconditions/containers/UserPermissionsPrecondition.cjs');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n.default = e;
  return Object.freeze(n);
}

var index_cjs__namespace = /*#__PURE__*/_interopNamespace(index_cjs);
var index_cjs__namespace$1 = /*#__PURE__*/_interopNamespace(index_cjs$1);

// src/index.ts
var ApplicationCommandRegistries = {
  acquire: ApplicationCommandRegistries_cjs.acquire,
  setDefaultBehaviorWhenNotIdentical: ApplicationCommandRegistries_cjs.setDefaultBehaviorWhenNotIdentical,
  setDefaultGuildIds: ApplicationCommandRegistries_cjs.setDefaultGuildIds,
  setBulkOverwriteRetries: ApplicationCommandRegistries_cjs.setBulkOverwriteRetries,
  getDefaultGuildIds: ApplicationCommandRegistries_cjs.getDefaultGuildIds,
  getDefaultBehaviorWhenNotIdentical: ApplicationCommandRegistries_cjs.getDefaultBehaviorWhenNotIdentical,
  getBulkOverwriteRetries: ApplicationCommandRegistries_cjs.getBulkOverwriteRetries,
  get registries() {
    return ApplicationCommandRegistries_cjs.registries;
  }
};
var CorePreconditions = {
  ClientPermissions: ClientPermissions_cjs.CorePrecondition,
  Cooldown: Cooldown_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  DMOnly: DMOnly_cjs.CorePrecondition,
  Enabled: Enabled_cjs.CorePrecondition,
  RunIn: RunIn_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  GuildNewsOnly: GuildNewsOnly_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  GuildNewsThreadOnly: GuildNewsThreadOnly_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  GuildOnly: GuildOnly_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  GuildPrivateThreadOnly: GuildPrivateThreadOnly_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  GuildPublicThreadOnly: GuildPublicThreadOnly_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  GuildTextOnly: GuildTextOnly_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  GuildVoiceOnly: GuildVoiceOnly_cjs.CorePrecondition,
  /** @deprecated Use {@link RunIn} instead. */
  GuildThreadOnly: GuildThreadOnly_cjs.CorePrecondition,
  NSFW: NSFW_cjs.CorePrecondition,
  UserPermissions: UserPermissions_cjs.CorePrecondition
};
var version = "5.2.1";

Object.defineProperty(exports, "AliasPiece", {
  enumerable: true,
  get: function () { return pieces.AliasPiece; }
});
Object.defineProperty(exports, "AliasStore", {
  enumerable: true,
  get: function () { return pieces.AliasStore; }
});
Object.defineProperty(exports, "LoaderError", {
  enumerable: true,
  get: function () { return pieces.LoaderError; }
});
Object.defineProperty(exports, "MissingExportsError", {
  enumerable: true,
  get: function () { return pieces.MissingExportsError; }
});
Object.defineProperty(exports, "Piece", {
  enumerable: true,
  get: function () { return pieces.Piece; }
});
Object.defineProperty(exports, "Store", {
  enumerable: true,
  get: function () { return pieces.Store; }
});
Object.defineProperty(exports, "StoreRegistry", {
  enumerable: true,
  get: function () { return pieces.StoreRegistry; }
});
Object.defineProperty(exports, "container", {
  enumerable: true,
  get: function () { return pieces.container; }
});
exports.PreconditionResolvers = index_cjs__namespace;
exports.Resolvers = index_cjs__namespace$1;
Object.defineProperty(exports, "ApplicationCommandRegistry", {
  enumerable: true,
  get: function () { return ApplicationCommandRegistry_cjs.ApplicationCommandRegistry; }
});
exports.ApplicationCommandRegistries = ApplicationCommandRegistries;
exports.CorePreconditions = CorePreconditions;
exports.version = version;
Object.keys(result).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return result[k]; }
  });
});
Object.keys(SapphireClient_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return SapphireClient_cjs[k]; }
  });
});
Object.keys(ArgumentError_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return ArgumentError_cjs[k]; }
  });
});
Object.keys(Identifiers_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Identifiers_cjs[k]; }
  });
});
Object.keys(PreconditionError_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return PreconditionError_cjs[k]; }
  });
});
Object.keys(UserError_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return UserError_cjs[k]; }
  });
});
Object.keys(Args_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Args_cjs[k]; }
  });
});
Object.keys(Plugin_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Plugin_cjs[k]; }
  });
});
Object.keys(PluginManager_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return PluginManager_cjs[k]; }
  });
});
Object.keys(symbols_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return symbols_cjs[k]; }
  });
});
Object.keys(Argument_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Argument_cjs[k]; }
  });
});
Object.keys(ArgumentStore_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return ArgumentStore_cjs[k]; }
  });
});
Object.keys(Command_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Command_cjs[k]; }
  });
});
Object.keys(CommandStore_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return CommandStore_cjs[k]; }
  });
});
Object.keys(InteractionHandler_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return InteractionHandler_cjs[k]; }
  });
});
Object.keys(InteractionHandlerStore_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return InteractionHandlerStore_cjs[k]; }
  });
});
Object.keys(Listener_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Listener_cjs[k]; }
  });
});
Object.keys(ListenerLoaderStrategy_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return ListenerLoaderStrategy_cjs[k]; }
  });
});
Object.keys(ListenerStore_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return ListenerStore_cjs[k]; }
  });
});
Object.keys(Precondition_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Precondition_cjs[k]; }
  });
});
Object.keys(PreconditionStore_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return PreconditionStore_cjs[k]; }
  });
});
Object.keys(ArgumentContexts_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return ArgumentContexts_cjs[k]; }
  });
});
Object.keys(CommandTypes_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return CommandTypes_cjs[k]; }
  });
});
Object.keys(Enums_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Enums_cjs[k]; }
  });
});
Object.keys(Events_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Events_cjs[k]; }
  });
});
Object.keys(ILogger_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return ILogger_cjs[k]; }
  });
});
Object.keys(Logger_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return Logger_cjs[k]; }
  });
});
Object.keys(IPreconditionContainer_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return IPreconditionContainer_cjs[k]; }
  });
});
Object.keys(PreconditionContainerArray_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return PreconditionContainerArray_cjs[k]; }
  });
});
Object.keys(PreconditionContainerSingle_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return PreconditionContainerSingle_cjs[k]; }
  });
});
Object.keys(IPreconditionCondition_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return IPreconditionCondition_cjs[k]; }
  });
});
Object.keys(PreconditionConditionAnd_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return PreconditionConditionAnd_cjs[k]; }
  });
});
Object.keys(PreconditionConditionOr_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return PreconditionConditionOr_cjs[k]; }
  });
});
Object.keys(ClientPermissionsPrecondition_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return ClientPermissionsPrecondition_cjs[k]; }
  });
});
Object.keys(UserPermissionsPrecondition_cjs).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return UserPermissionsPrecondition_cjs[k]; }
  });
});
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.cjs.map